#
# spec file for package inn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if "%{_libexecdir}"=="/usr/libexec"
%define search usr\\/libexec
%define nslash usr/libexec
%else
%define search usr\\/lib
%define nslash usr/lib
%endif
Name:           inn
BuildRequires:  bison
BuildRequires:  gdbm-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  postfix
BuildRequires:  python3-devel
BuildRequires:  zlib-devel
BuildRequires:  perl(GD)
BuildRequires:  perl(MIME::Parser)
URL:            https://www.isc.org/othersoftware/#INN
Summary:        InterNetNews
License:        BSD-4-Clause AND GPL-2.0-or-later
Group:          Productivity/Networking/News/Servers
Provides:       inn_pkg
Provides:       nntp_daemon
Conflicts:      cnews
Conflicts:      mininews
Conflicts:      nntpd
PreReq:         perl
PreReq:         permissions
PreReq:         group(news)
PreReq:         group(uucp)
PreReq:         user(news)
Requires:       perl-MIME-tools
Requires:       perl(GD)
Requires:       perl(MIME::Parser)
%{?systemd_requires}
%{?libperl_requires}
Version:        2.6.5
Release:        3.6
%define PatchVersion -%{version}
Source:         https://downloads.isc.org/isc/inn/inn%{PatchVersion}.tar.gz
Source1:        doc-inn.tar.bz2
Source2:        pubring.pgp
Source3:        inn-emptydb.tar.gz
Source4:        inn.reg
Source5:        https://downloads.isc.org/isc/inn/inn%{PatchVersion}.tar.gz.asc
Source6:        %{name}.keyring
Source7:        inn.service
Patch0:         inn-%{version}.diff
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#

%description
Rich Salz's InterNetNews news transport system.

%package devel
Requires:       %name = %version
Summary:        InterNetNews development files
Group:          Development/Languages/C and C++
Requires:       bison
Requires:       gdbm-devel
Requires:       pam-devel
Requires:       zlib-devel

%description devel
Rich Salz's InterNetNews news transport system.

This package contains the files needed to develop software depending on
inn.

%package -n mininews
Summary:        Inews - Post News from an NNTP Client
Group:          Productivity/Networking/News/Utilities
Provides:       nntp_daemon
PreReq:         permissions
PreReq:         group(news)
PreReq:         group(uucp)
PreReq:         user(news)

%description -n mininews
Rich Salz's InterNetNews news transport system.

%prep
%setup -n inn%{PatchVersion}
%setup -n inn%{PatchVersion} -D -T -a 1
%setup -n inn%{PatchVersion} -D -T -a 3
sed -e 's-@LIBEXECDIR@-%{_libexecdir}-g' -i  %{SOURCE7} %{PATCH0}
%patch -P 0 -p1
cp -a $RPM_SOURCE_DIR/pubring.pgp .

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
LDFLAGS="-pie" CFLAGS="$RPM_OPT_FLAGS -pipe -fno-strict-aliasing -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE -fPIE -fstack-protector -fcommon" ./configure \
		--enable-uucp-rnews \
		--enable-setgid-inews \
		--prefix=%{_libexecdir}/news \
		--sysconfdir=/etc/news \
		--mandir=%{_mandir} \
		--disable-shared \
		--enable-tagged-hash \
		--with-perl \
		--with-zlib \
        --with-python \
        --with-openssl \
		--with-sendmail=/usr/sbin/sendmail \
		--with-news-user=news \
		--with-news-group=news \
		--with-news-master=news \
		--with-db-dir=/var/lib/news \
		--with-run-dir=/var/run/news \
		--with-log-dir=/var/log/news \
		--with-http-dir=/var/log/news/http \
		--with-spool-dir=/var/spool/news \
		--with-tmp-dir=/var/spool/news/tmp
make
cp site/inn.conf inn.conf.tmp
echo 'domain: test.com' >> inn.conf.tmp
echo "runasuser: $(id -n -u)" >> inn.conf.tmp
echo "runasgroup: $(id -n -g)" >> inn.conf.tmp
INNCONF=inn.conf.tmp expire/makedbz -f `pwd`/inn-emptydb/history -s 666666
rm -f inn.conf.tmp

%install
mkdir -p %{buildroot}/etc
mkdir -p %{buildroot}%{_libexecdir}
mkdir -p %{buildroot}/usr/bin
mkdir -p %{buildroot}/var/lib
mkdir -p %{buildroot}/var/log
mkdir -p %{buildroot}/var/spool
mkdir -p %{buildroot}%{_mandir}
#
make DESTDIR=%{buildroot} OWNER= ROWNER= install
# rename list manpage as it conflicts with the man-pages package
for i in %{buildroot}%{_mandir}/*/* ; do
  if test -L "$i" ; then
    il=$(readlink "$i")
    ln -s "$il.gz" "$i.gz"
    rm -f "$i"
  else
    gzip -nf9 "$i"
  fi
done
chmod 444 %{buildroot}%{_libexecdir}/news/lib/*.a
# those just die("BerkeleyDB support not compiled");
rm %{buildroot}%{_libexecdir}/news/bin/ovdb_server
rm %{buildroot}%{_libexecdir}/news/bin/ovdb_stat
ln %{buildroot}%{_libexecdir}/news/bin/ovdb_init %{buildroot}%{_libexecdir}/news/bin/ovdb_server
ln %{buildroot}%{_libexecdir}/news/bin/ovdb_init %{buildroot}%{_libexecdir}/news/bin/ovdb_stat
#
#
#
%define installnews install -o news -g news -m
%define installnews install -m
%define installroot install -o root -g root -m
%define installroot install -m
%{installnews} 0755 	-d		%{buildroot}/var/log/news/http
%{installnews} 0644	samples/subscriptions	%{buildroot}/etc/news
%{installnews} 0644	distributions	%{buildroot}/etc/news
%{installnews} 0644	crontab.sample	%{buildroot}/etc/news
%{installnews} 0644	profile		%{buildroot}/etc/news/.profile
%{installnews} 0755 	-d		%{buildroot}/etc/news/.pgp
%{installnews} 0600	pubring.pgp	%{buildroot}/etc/news/.pgp
%{installnews} 0644	samples/send-uucp.cf	%{buildroot}/etc/news
%{installnews} 0755 	-d		%{buildroot}/var/log/news/http
%{installnews} 0755 	-d		%{buildroot}/var/log/news/http/pics
%{installnews} 0555	convertspool	%{buildroot}%{_libexecdir}/news/bin
%{installnews} 0755 	-d		%{buildroot}%{_libexecdir}/news/include
%{installnews} 0755 	-d		%{buildroot}%{_libexecdir}/news/include/inn
#
#
#
%{installnews} 0644	inn-emptydb/*	%{buildroot}/var/lib/news
%{installnews} 0755 	-d		%{buildroot}/var/lib/news/backoff
#
# compat links
#
ln -sf bin/inews		%{buildroot}%{_libexecdir}/news/inews
ln -sf %{_libexecdir}/news/bin/inews	%{buildroot}/usr/bin/inews
ln -sf %{_libexecdir}/news/bin/rnews	%{buildroot}/usr/bin/rnews
#
# other links
#
ln -sf ../innfeed.status	%{buildroot}/var/log/news/http/innfeed.status.txt
ln -sf ../inn.status		%{buildroot}/var/log/news/http/inn.status.txt
#
#
#
%{installnews} 0755	-d		%{buildroot}/usr/lib/systemd/system
%{installroot} 0644	%{SOURCE7}	%{buildroot}/usr/lib/systemd/system/inn.service
%{installnews} 0755	-d		%{buildroot}/usr/sbin
ln -sf service 	%{buildroot}/usr/sbin/rcinn
#
touch				%{buildroot}/var/log/news/news
touch				%{buildroot}/var/log/news/news.notice
touch				%{buildroot}/var/log/news/news.err
touch				%{buildroot}/var/log/news/news.crit
touch				%{buildroot}/var/log/news/inn.status
touch				%{buildroot}/var/log/news/innfeed.status
#
# SLP regfile
#
%{installroot} 0755	-d		%{buildroot}/etc/slp.reg.d
%{installroot} 0644	%{SOURCE4}	%{buildroot}/etc/slp.reg.d/
# /run/news
mkdir -p $RPM_BUILD_ROOT/usr/lib/tmpfiles.d/
echo "d /run/news 0750 news news -" > %{buildroot}/usr/lib/tmpfiles.d/inn.conf

#
# build filelist
#
%define filelist %{name}-filelist
find %{buildroot} -type d -printf "/%%P\n" | awk '
! /^\/(etc|%{search}|var\/lib|var\/log|var\/spool|var\/run)\/news/ { next }
$0 == "/etc/news"     { next }
$0 == "%{_libexecdir}/news/include" { next }
$0 == "%{_libexecdir}/news/include/inn" { next }
$0 == "/var/run/news" { next }
{ pfx="" }
$0 == "%{_libexecdir}/news" { pfx = "%%attr(755,root,root) " }
$0 == "/var/lib/news" { pfx = "%%attr(755,news,news) " }
$0 == "%{_libexecdir}/news/bin" { pfx = "%%attr(755,root,root) " }
$0 == "/var/spool/news" { pfx = "%%attr(775,news,news) " }
$0 == "/var/run/news" { pfx = "%ghost %%attr(750,news,news) "}
/\/news/ {
 	if (!match(pfx, /%%attr/)) pfx = "%%attr(-,news,news) " pfx
}
{ print "%dir " pfx $0 }
' > %{filelist}
find %{buildroot} ! -type d -printf "/%%P\n" | awk '
{ pfx="" }
/^\/%{search}\/news\/include/              { next }
/^\/%{search}\/news\/lib\/.*\.a/             { next }
$0 == "%{_libexecdir}/news/bin/inews"           { pfx="%attr(2555,news,news) " }
$0 == "%{_libexecdir}/news/bin/rnews"           { pfx="%attr(4550,news,uucp) " }
$0 == "%{_libexecdir}/news/bin/innbind"         { pfx="%verify(not mode) %attr(4550,root,news) " }
/^\/(etc\/news|%{search}\/news\/bin\/filter|var\/lib\/news)\// {
	pfx="%config(noreplace) "pfx
}
/\/man\/man/ {
	pfx="%doc %attr(444,root,root) "pfx
}
/^\/var\/log\/news\/(news|inn\.status|innfeed\.status)/ {
	pfx="%ghost %attr(644,news,news) "pfx
}
/\/news\// {
 	if (!match(pfx, /%%attr/)) pfx = "%%attr(-,news,news) " pfx
}
/^\/etc\/slp\.reg\.d\// { next }
{ print pfx $0 }
' >> %{filelist}

#
#
#

%pre
test -f var/log/news && mv var/log/news var/log/news.bak
%service_add_pre inn.service
exit 0

%post
runuser -u news -g news touch \
    var/log/news/news.notice \
    var/log/news/news.err \
    var/log/news/news.crit \
    var/log/news/news \
    var/log/news/inn.status \
    var/log/news/innfeed.status
if test -e %{nslash}/news/bin/control/version -o -e %{nslash}/news/bin/inndstart ; then
    rm -f etc/news/inn.conf.OLD
    rm -f etc/news/newsfeeds.OLD
    %{nslash}/news/bin/innupgrade etc/news
fi
if ! test -d /var/run/news ; then
    install -d -m 750 -o news -g news /var/run/news
fi
%set_permissions %{_libexecdir}/news/bin/innbind %{_libexecdir}/news/bin/inews %{_libexecdir}/news/bin/rnews
%service_add_post inn.service
%tmpfiles_create inn.conf

%post -n mininews
%set_permissions %{_libexecdir}/news/bin/inews %{_libexecdir}/news/bin/rnews
%tmpfiles_create inn.conf

%verifyscript
%verify_permissions -e %{_libexecdir}/news/bin/innbind -e %{_libexecdir}/news/bin/inews -e %{_libexecdir}/news/bin/rnews

%verifyscript -n mininews
%verify_permissions -e %{_libexecdir}/news/bin/inews -e %{_libexecdir}/news/bin/rnews

%preun
%service_del_preun inn.service

%postun
%service_del_postun inn.service

%files -f %{filelist}
%defattr(-,root,root)
%dir			/etc/slp.reg.d
%config(noreplace)	/etc/slp.reg.d/inn.reg
%doc NEWS INSTALL README*
%doc doc-inn/*

%files devel
%defattr(-,root,root)
%{_libexecdir}/news/include
%{_libexecdir}/news/lib/*.a

%files -n mininews
%defattr(-,root,root)
%config(noreplace)      /etc/news/inn.conf
%dir                    %{_libexecdir}/news/bin
%attr(4550,news,uucp)   %{_libexecdir}/news/bin/rnews
%attr(2555,news,news)   %{_libexecdir}/news/bin/inews
                        /usr/bin/[ri]news
                        %{_libexecdir}/news/[ri]news
%doc                    %{_mandir}/*/inn.conf.*
%doc                    %{_mandir}/*/[ri]news.*

%changelog
* Mon Aug 19 2024 Giacomo Comes <gcomes.obs@gmail.com>
- replace /var/run/news with /run/news in /usr/lib/tmpfiles.d/inn.conf
  * avoid warning: Line references path below legacy directory /var/run
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Jul 14 2022 Michael Ströder <michael@stroeder.com>
- Update to version 2.6.5:
  * A new step in INN development has been achieved with the migration of
    the INN project to GitHub.
  * An up-to-date nocem.ctl file is provided with this release.  You
    should manually update your nocem.ctl file with the new information
    recorded about NoCeM issuers, and make sure the right PGP keys are
    present on your system.
  * Up-to-date control.ctl and moderators files are provided with this
    release.  You should manually update them (notably for the fido7.*
    hierarchy).
  * Added a stricter validation of article numbers given in NNTP commands
    so that numbers superior to 2^31 are correctly considered invalid.
    Thanks to Richard Kettlewell for the patch.
  * Added a check in rc.news for the existence of the *pathrun* directory.
    INN won't start until this directory is writable.  Previously, it
    bailed out quickly after starting, without clear logs about why it
    failed.
  * Fixed parallel builds using "make -j".  Thanks to Richard Kettlewell
    for the path.
  * nnrpd now properly gathers timer statistics when a compression layer
    is active.
  * nnrpd now properly discards data received from a news client after a
    timeout when a TLS layer is active.  It previously tried to read
    incoming data before closing the socket, leading to decoding errors
    from an underlying compression or SASL layer.
  * innfeed and ovdb_stat now generate status reports in valid HTML
    syntax.
  * Fixed a bug in the buffindexed overview that prevented it from working
    on several systems, amongst them FreeBSD.  Unsupported, and useless,
    permission bits were given to semaphores.
  * Fixed the detection of library paths at configure time: multilib
    directories (lib32 or lib64) are now also used if they exist, even it
    the system does not use multilib.  It will notably fix the detection
    of the OpenSSL 3.0.0 library.
  * The *tlscertfile* parameter in inn.conf now permits the use of a
    complete certificate chain, instead of necessarily having to use
  * tlscafile* for additional certificates.
  * Added support for the new OpenSSL 3.0.0 API, which deprecated a few
    functions.
  * The inn.conf default value for *tlsprotocols* no longer contains TLS
    versions 1.0 and 1.1, which have been deprecated by RFC 8996.
  * A new inn.conf parameter has been added to tune the length of the
    queue of pending connections to innd, nnrpd and the "ovdb" overview
    storage method: the *maxlisten* parameter now permits configuring
    their listen backlog, whose previously hard-coded values were 128 for
    nnrpd and 25 for the others, which was not high enough for some uses.
    The default value is now 128 for all of them, and configurable in
    inn.conf.  Thanks to Kevin Bowling for the patch.
  * The name of seven man pages for routines built in libinn(3) are now
    prefixed with libinn_ so as not to consume namespace and conflict with
    other packages (notably, the list(3) and uwildmat(3) man pages are now
    named libinn_list(3) and libinn_uwildmat(3)).
  * Other minor bug fixes and documentation improvements, notably a
    revised installation checklist and a section summarizing the most used
    configuration at the beginning of a few complex man pages.
- delete inn-2.6.4.diff patch
- add inn-2.6.5.diff patch instead
* Wed Dec  1 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.6.4:
  + Bug Fix: nnrpd now adapts the length of the DH parameter used
    during a DHE key exchange so as to comply with the security
    level OpenSSL 1.1.0 or later expects.
  + New Features:
  * Added support for systemd notifications and socket
    activation. Use of more features provided by systemd,
    including more notifications, will come in future releases.
  * cnfsstat now also returns information about retired CNFS
    buffers: buffers mentioned in cycbuff.conf as a cycbuff but
    not declared in a metacycbuff.
  * Switch default innreport behaviour to the common practice of
    externalizing CSS into a separate file. Its name can be
    configured with the html_css_url parameter in innreport.conf.
    If this parameter is unset, the default innreport.css file
    name will be used and innreport will generate this CSS file
    for you. Previously generated reports are kept untouched,
    though, and will still contain inline CSS if you had not
    already set the html_css_url parameter in previous INN
    versions.
  * sm can now read and store any number of articles given in
    wire format on its standard input when both -s and -R are
    used. Only native format was previously possible.
  * Added new -a flag to rnews to disallow, if needed, the use of
    additional unpackers from the rnews.libexec sub-directory of
    pathbin (as set in inn.conf); only rnews and cunbatch will
    then be recognized as valid batch commands.
  * Added new -b flag to rnews to save rejected articles in the
    bad sub-directory of pathincoming (as set in inn.conf).
    Otherwise, rnews just logs and discards any articles that are
    rejected or cannot be parsed for some reason.
  * Added new -d flag to rnews to log via syslog the message-ID
    and the Path header body of each article rejected as a
    duplicate.
  * Added new --enable-hardening-flags configure-time option,
    enabled by default, to use hardening build flags like -fPIE
    and -fstack-protector-strong. This option can easily be
    disabled if the compiler or the platform does not support
    them well. More hardening build flags will eventually be
    added in future releases.
- Rename inn-2.6.3.diff to inn-2.6.4.diff.
- Use url in sources as far as possible.
* Wed Sep 22 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * inn.service
* Mon Jul 12 2021 Steve Kowalik <steven.kowalik@suse.com>
- Switch BuildRequires to python3-devel, to build using Python 3.
* Sun Dec 20 2020 Callum Farmer <gmbr3@opensuse.org>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Mon Nov  9 2020 mls@suse.de
- rename the list.3 manpage to list-inn.3 as it conflicts with the
  list.3 manpage from the man-pages 5.09 package [bnc#1178534]
* Sun Jun 14 2020 Lars Vogdt <lars@linux-schulserver.de>
- update to inn-2.6.3
  + Fixed the selection of the elliptic curve to use with OpenSSL 1.1.0 or
    later; NIST P-256 was enforced instead of using the most secure curve.
  + A new inn.conf parameter has been added to fine-tune the cipher suites
    to use with TLS 1.3:  the *tlsciphers13* now permits configuring them.
    A separate cipher suite configuration parameter is needed for TLS 1.3
    because TLS 1.3 cipher suites are not compatible with TLS 1.2, and
    vice-versa.  In order to avoid issues where legacy TLS 1.2 cipher
    suite configuration configured in the *tlsciphers* parameter would
    inadvertently disable all TLS 1.3 cipher suites, the inn.conf
    configuration has been separated out.
  + Fixed a regression since INN 2.6.1 that prevented articles with
    internationalized header fields (that is to say encoded in UTF-8) from
    being posted.
  + Support for Python 3 has been added to INN.  Embedded Python filtering
    and authentication hooks for innd and nnrpd can now use version 3.3.0
    or later of the Python interpreter.  In the 2.x series, version 2.3.0
    or later is still supported.
  + When configuring INN with the --with-python flag, the "PYTHON"
    environment variable, when set, is used to select the interpreter to
    embed.  Otherwise, it is searched in standard paths.
  + In case you change the Python interpreter to embed, make sure that the
    Python scripts you use are written in the expected syntax for that
    version of the Python interpreter.  Notably, buffer objects have been
    replaced with memoryview objects in Python 3, and UTF-8 encoding now
    really matters for string literals (Python 3 uses bytes and Unicode
    objects).
  + INN documentation and samples of Python hooks have been updated to
    provide more examples.
  + When a Python or Perl filter hook rejects an article, innd now
    mentions the reason in response to CHECK and TAKETHIS commands.
    Previously, the reason was given only for the IHAVE command.
  + nnrpd now properly logs the hostname of clients whose connection
    failed owing to an issue during the negotiation of a TLS session or
    high load average.
- renamed and refreshed inn-2.6.2.diff to inn-2.6.3.diff
- fix upstream URL
- (build)require openssl-devel and python-devel and build with
  - -with-python and --with-openssl support
- remove outdated/unknown configure options:
  - -enable-dual-socket, --enable-ipv6 and --with-etc-dir
- use 'Development/Languages/C and C++' as RPM group for the -devel
  package
- require appropriate -devel packages for -devel package installs
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Add -fcommon to allow building against GCC10
* Fri Jan 24 2020 mls@suse.de
- change user to news before touching files in /var/log/news
  [bnc#1154302] [CVE-2019-3692]
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Fri Dec 14 2018 mls@suse.de
- update to inn-2.6.2
  * support for compressed newsfeeds
  * many bug fixes and documentation improvements
  * dropped patch: inn-2.5.4.diff
  * new patch: inn-2.6.2.diff
- use native systemd service [#1116017]
  * new file: inn.service
* Tue Feb 21 2017 kukuk@suse.de
- Add directories formerly owned by filesystem
- Require group and user news
- Require group uucp
* Wed Oct 26 2016 kukuk@suse.de
- Fix tmpfiles.d usage to give it at least a chance to work
* Sat Dec 13 2014 Led <ledest@gmail.com>
- fix bashisms
- updated patches:
  + inn-2.5.4.diff
* Thu Dec 11 2014 mls@suse.de
- enable IPv6
- get rid of gpg-offline as we nowadays check signatures in
  the source validator
* Wed Jul 16 2014 mls@suse.de
- update to inn-2.5.4
  * updated control.ctl file
  * improved signature checking in pgpverify
  * new "htmlstatus" config option
  * many bugs fixed
  * removed patches: inn-linereset.diff
  * renamed patches: inn-2.5.2.diff -> inn-2.5.4.diff
- fix innbind file mode
- fix empty history database on 64bit [bnc#876287]
* Mon Sep  9 2013 mls@suse.de
- make /usr/lib/news/bin owned by root
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Tue Nov 27 2012 sbrabec@suse.cz
- Verify GPG signature.
* Mon Sep 17 2012 coolo@suse.com
- fix ownership of directories so subpackages can be installed with
  rpm 4.10
* Tue Sep  4 2012 mls@suse.de
- fix starttls command injection issue [bnc#776967]
- fix /var/run/news permission and handling.
* Tue Jun 19 2012 aj@suse.de
- Use set_permissions instead of run_permissions.
- Handle /var/run on tmpfs.
* Thu Mar 22 2012 cfarrell@suse.com
- license update: GPL-2.0+ and BSD-4-Clause
  SPDX format and also include *.in files from control/ as BSD-4-Clause
* Fri Mar 16 2012 lmuelle@suse.de
- require perl-MIME-tools
* Wed May 19 2010 mls@suse.de
- adapt innbind modes to permissions file
* Thu Apr  8 2010 mls@suse.de
- compile with largefile support
* Wed Apr  7 2010 mls@suse.de
- update to inn-2.5.2
  * implement CAPABILITIES command
  * decent parser for NNTP commands
  * multiple LIST commands allow pattern matching
* Fri Sep  4 2009 mls@suse.de
- fix fd leak [bnc#525827]
* Sun Aug 30 2009 coolo@novell.com
- provide Patch0
* Thu Jul 10 2008 mls@suse.de
- fix segfault in perl_call_argv [bnc#405186]
* Thu Jun 19 2008 werner@suse.de
- Add missing Provides to the init script
* Wed May 30 2007 mls@suse.de
- split devel package
- remove some file duplicates
* Mon Apr  2 2007 rguenther@suse.de
- Add gdbm-devel BuildRequires.
* Thu Mar 29 2007 rguenther@suse.de
- Add bison BuildRequires.
* Wed Feb 14 2007 schwab@suse.de
- Fix building as non-root.
* Mon Nov 13 2006 mls@suse.de
- initialize mechusing variable to shut up intel compiler [#197713]
* Mon Jan 30 2006 mls@suse.de
- add -fstack-protector to CFLAGS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jun 26 2005 ro@suse.de
- build with fPIE/pie
* Fri Mar 11 2005 mls@suse.de
- fix off-by-one error in parsedate_rfc2822
* Fri Mar  4 2005 mls@suse.de
- package startinnfeed with mode 4755
* Fri Feb  4 2005 mls@suse.de
- update to inn-2.4.2
* Wed Nov 10 2004 ro@suse.de
- permissions handling fix
* Sun Apr  4 2004 mls@suse.de
- made /usr/lib/news/bin owned by root:root as it contains
  a suid-root program
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Thu Mar 18 2004 mls@suse.de
- provide slp regfile
- pack manpages with owner root:root
* Fri Feb 27 2004 mls@suse.de
- update to inn-2.4.1
- updated inn faq
* Fri Jan 16 2004 kukuk@suse.de
- Cleanup neededforbuild
* Mon Jan 12 2004 adrian@suse.de
- package startinnfeed with 0555 permissions
  (following permissions scripts)
* Fri Jan  9 2004 thomas@suse.de
- fixed remotely exploitable buffer overflow (#33882)
* Tue Sep  2 2003 mls@suse.de
- use stop_on_removal/restart_on_update macros
- convertspool: use split -a 5
* Wed Jul 30 2003 mls@suse.de
- update to inn-2.4.0
* Mon Jun 23 2003 mls@suse.de
- create link targets as ghost
- don't pack /etc/news, /usr/lib/news, /var/lib/news, they
  are already in filesystem.rpm
* Thu Apr 10 2003 ro@suse.de
- fix deprecated head/tail calling syntax (-1)
* Mon Mar  3 2003 mls@suse.de
- touch /var/log/news/news in postinstall (#24555)
* Fri Jan 10 2003 mls@suse.de
- update to inn-2.3.4
* Wed Sep 11 2002 mls@suse.de
- corrected Required-Start in rc file (#19402)
* Tue Aug 20 2002 mls@suse.de
- added PreReqs
- dropped superfluous (and dangerous) "Provides: inn"
* Fri Aug  9 2002 mls@suse.de
- made it work with threaded perl-5.8.0
* Fri Jul 12 2002 mls@suse.de
- fixed postinstall script to be sh -e resistant
- check if compress binary really works in uucp scripts
* Tue Jul  2 2002 meissner@suse.de
- rerun auto* tools.
* Thu May  2 2002 mls@suse.de
- use gzip if compress is not available (bug #15793)
- make inn header files available, suck needs them
* Thu Apr  4 2002 mls@suse.de
- fix LIBOBJS in configure.in for new autoconf version
* Wed Mar  6 2002 mls@suse.de
- put innd in xrefslave mode in convertspool script
- fix innconfval segfault if pathhost is not set
* Mon Feb 25 2002 mls@suse.de
- fixed permissions of inn libraries
- added comment about overchan and controlchan
* Thu Feb 14 2002 mls@suse.de
- added detection of old history format to rc.news
- added convertspool script
- updated README.linux
- use "rc.news stop" to stop inn
* Mon Feb 11 2002 mls@suse.de
- update to inn-2.3.2.
- rcinn now LSB compliant.
* Tue Jan 15 2002 ro@suse.de
- removed START_INN
* Tue Jan 15 2002 egmont@suselinux.hu
- Removed colons from startup/shutdown messages.
* Wed Jun 13 2001 schwab@suse.de
- Fix for new autoconf.
* Tue Mar 13 2001 ma@suse.de
- Explicitly set permissions for inews(sgid news), rnews(suid news),
  inndstart and startinnfeed (both suid root) in specfile.
* Mon Dec  4 2000 ma@suse.de
- adopt LSB runlevel and init script scheme
* Thu Nov 23 2000 ma@suse.de
- IPv6 patch removed
* Fri Oct 13 2000 ma@suse.de
- Update to inn-2.2.3
- IPv6 patch form http://bofh.st/ipv6/downloads/sith.mimuw.edu.pl
  added.
* Wed Sep  6 2000 ma@suse.de
- fixed restart, status and reload section in rcinn (#3889)
* Thu Jul 27 2000 ma@suse.de
- fixed wrong ownership of ~news
* Thu Jul  6 2000 ma@suse.de
- fixed wrong pathnames in send-uucp.pl
* Mon Jun 19 2000 ma@suse.de
- fixes some possible on-stack buffer overflows
- using BuildRoot
- add directories for control, control.cancel and junk (#2644)
- article filters marked as config (#1760)
* Fri Mar 31 2000 schwab@suse.de
- Update config.{guess,sub} from automake.
* Wed Mar  1 2000 ro@suse.de
- use %%{_mandir}
* Wed Mar  1 2000 werner@suse.de
- Fix config.guess selection
* Wed Jan 12 2000 ma@suse.de
- update to 2.2.2 STABLE snapshot 2000-10-01.
  Y2K bugs fixed
- added rnews to mininews subpackage
* Wed Nov 24 1999 ma@suse.de
- update to 2.2.1 STABLE snapshot 1999-11-23.
  fixes some bugs that cause inn to crash.
* Mon Sep 20 1999 ro@suse.de
- added Provides nntp_daemon for mininews
* Mon Sep 20 1999 ro@suse.de
- added Provides nntp_daemon
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug 30 1999 ma@suse.de
- update to 2.2.1 (Fixes for possible buffer overflow)
* Tue Jan 19 1999 uli@suse.de
- update to newer inn sources
- do not have an open inn server as default configuration
* Tue Jan 19 1999 uli@suse.de
- mininews: fixed missing binary, added /etc/news/inn.conf
* Fri Jan  8 1999 florian@suse.de
- add the FAQ again
- add /usr/sbin/rcinn
* Thu Dec 17 1998 florian@suse.de
- update to current cvs-version
- fix innfeed.conf to use "inn.feed" directory
* Fri Dec 11 1998 ro@suse.de
- update to 2.2
* Sat Nov 14 1998 ro@suse.de
- fix type-conflict for mmap in include/clibrary.h
- build mininews from same specfile
* Sun Sep 20 1998 ro@suse.de
- dont redeclare sys_errlist for glibc
- change return value of exit in include/clibrary.h to explicit "void"
- add -lcrypt for glibc
* Fri Oct 24 1997 florian@suse.de
- rework autobuild support
- update to inn 1.7
* Tue Oct 21 1997 ro@suse.de
- ready for autobuild
* Mon Jun  2 1997 florian@suse.de
- mv fillup to /var/adm/fillup-templates/
- include correct postinstall script
* Tue May 27 1997 florian@suse.de
- always use gzip to decompress news-batches
* Wed Apr  9 1997 florian@suse.de
- all log files are in /var/lib/news/log
- inn doesn't try to look at syslog files
- pgp-verification is ready to be used
- all known security patches and some bug-reports installed
- new faq files and docu cleanup
